@@ -3,5 +3,5 @@
 reV-SAM interface module
 """
 from .econ import LCOE, SingleOwner
-from .generation import PV, CSP, LandBasedWind, OffshoreWind
+from .generation import Pvwattsv5, Pvwattsv7, TcsMoltenSalt, WindPower
 from .windbos import WindBos
