@@ -39,6 +39,7 @@ class SAMAnalysisConfig(AnalysisConfig):
         self._pc = None
         self._default_timeout = 1800
         self._output_request = None
+        self._site_data = None
 
     @property
     def technology(self):
@@ -109,6 +110,18 @@ class SAMAnalysisConfig(AnalysisConfig):
 
         return self._output_request
 
+    @property
+    def site_data(self):
+        """Get the site-specific SAM inputs data file.
+
+        Returns
+        -------
+        site_data : str | NoneType
+            Target path for site-specific SAM inputs data file.
+        """
+        self._site_data = self.get('site_data', self._site_data)
+        return self._site_data
+
     def parse_sam_config(self):
         """Get the SAM configuration object.
 
@@ -245,7 +258,6 @@ class EconConfig(SAMAnalysisConfig):
         """
         super().__init__(config)
         self._cf_files = None
-        self._site_data = None
 
     @property
     def cf_file(self):
@@ -258,18 +270,6 @@ class EconConfig(SAMAnalysisConfig):
         """
         return self['cf_file']
 
-    @property
-    def site_data(self):
-        """Get the site-specific data file.
-
-        Returns
-        -------
-        site_data : str | NoneType
-            Target path for site-specific data file.
-        """
-        self._site_data = self.get('site_data', self._site_data)
-        return self._site_data
-
     @property
     def dirout(self):
         """Get the output directory, look for key "output_directory" in the
