@@ -328,7 +328,7 @@ def multi_year_slurm(ctx, alloc, walltime, feature, memory, conda_env,
         out = slurm_manager.sbatch(slurm_cmd, alloc=alloc, memory=memory,
                                    walltime=walltime, feature=feature,
                                    name=name, stdout_path=stdout_path,
-                                   conda_env=conda_env, module=module)
+                                   conda_env=conda_env, module=module)[0]
         if out:
             msg = ('Kicked off reV multi-year collection job "{}" '
                    '(SLURM jobid #{}).'.format(name, out))
